import { createRouter, createWebHistory, RouteRecordRaw } from "vue-router";

export const Layout = () => import("@/layout/index.vue");

// 静态路由
export const constantRoutes: RouteRecordRaw[] = [
  {
    path: "/redirect",
    component: Layout,
    meta: { hidden: true },
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("@/views/redirect/index.vue"),
      },
    ],
  },

  {
    path: "/login",
    component: () => import("@/views/login/index.vue"),
    meta: { hidden: true },
  },

  {
    path: "/",
    name: "/",
    component: Layout,
    redirect: "/main",
    children: [
      {
        path: "main",
        component: () => import("@/views/main/main.vue"),
        name: "main",

        meta: {
          title: "综合管理平台",
          icon: "homepage",
        },
      },
    ],
  },
  {
    path: "/totalScreen",
    component: () => import("@/views/big-screens/TotalScreen.vue"),
    name: "totalScreen",
    meta: { hidden: true },
  },
  {
    path: "/mainScreen",
    component: () => import("@/views/screens/mainScreen.vue"),
    name: "mainScreen",
    meta: { hidden: true },
  },
  {
    path: "/users",
    component: () => import("@/views/sets/users.vue"),
    name: "users",
    meta: { hidden: true },
  },

  {
    path: "/:pathMatch(.*)*", // 必备
    component: () => import("@/views/error-page/404.vue"),
  },
];

/**
 * 创建路由
 */
const router = createRouter({
  history: createWebHistory(),
  routes: constantRoutes,
  // 刷新时，滚动条位置还原
  scrollBehavior: () => ({ left: 0, top: 0 }),
});

/**
 * 重置路由
 */
export function resetRouter() {
  router.replace({ path: "/login" });
}

export default router;
